====================================
Review Board Code Base Documentation
====================================


Introduction
============

This is a set of guides on the Review Board codebase. They cover the
process for developing Review Board, information on writing third party
modules, and contributing to the project.

Review Board is written in the `Python`_ programming language and makes use
of the `Django`_ web framework.

The source code for Review Board is available from our `Git repository`_.

.. _`Git repository`: https://github.com/reviewboard/reviewboard/
.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/


Contributing
============

.. toctree::
   :maxdepth: 1

   getting-started
   contributing-patches
   custom-forks
   faq


Styles and Standards
====================

.. toctree::
   :maxdepth: 1

   git/clean-commits
   writing-good-descriptions
   coding-standards


Documentation Guides
====================

.. toctree::
   :maxdepth: 1

   docs/writing-codebase-docs
   generating-documentation


Unit Test Guides
================

.. toctree::
   :maxdepth: 1

   unit-tests/running-tests
   unit-tests/fixtures


Database Guides
===============

.. toctree::
   :maxdepth: 1

   tasks/database-evolutions


Related Resources
=================

* `Django documentation`_
* `The Django Book`_
* `Git Cheat Sheets`_

.. _`Django documentation`: https://docs.djangoproject.com/
.. _`The Django Book`: http://djangobook.com/
.. _`Git Cheat Sheets`:
   https://training.github.com/kit/downloads/github-git-cheat-sheet.pdf
